@@ -2,7 +2,7 @@
  *
  * (c) 2006 Thierry MERLE <thierry.merle@free.fr>
  * (c) 2009, 2010 Louis Lagendijk
- * (c) 2014 Markus Heinz
+ * (c) 2014, 2022 Markus Heinz
  *
  * Code taken from epson.c. Commands taken from CanonUtil 0.07 
  * (http://xwtools.automatix.de/)
@@ -28,6 +28,7 @@
 #include "util.h"
 #include "bjnp.h"
 #include "canon.h"
+#include "canon_xml.h"
 #include "printer-io.h"
 
 #ifdef DEBUG
@@ -273,6 +274,9 @@ const static int MAX_NUMBER_OF_MODELS =
 #define LEVEL_LOW_40 40
 #define LEVEL_OUT 0
 
+/* Increased buffer size to potentially hold a XML document */
+#define BIG_BUFLEN (1024 * 1024)
+
 /* This funtion retrieves the ink level of an Canon printer conncected to
  * the specifies port and portnumber
  * Ink levels are binary: Normal or Low
@@ -293,10 +297,11 @@ int get_ink_level_canon(const int port, const char* device_file,
   char command[256];
   int length = 0;
   int i = 0;
-  char buffer[BUFLEN];
+  char buffer[BIG_BUFLEN];
   char *indexDOC = NULL, *indexDWS = NULL, *indexCHD = NULL, *indexCIR = NULL;
   int retry = 6; /* You can change this, but keep same parity */
   levelTab lt;
+  int xmlFound = 0;
 
   if ((port == BJNP) || (port == CUSTOM_BJNP)) {
     bjnp_get_printer_status(port, device_file,  portnumber, buffer);
@@ -349,8 +354,8 @@ int get_ink_level_canon(const int port, const char* device_file,
 	return COULD_NOT_WRITE_TO_PRINTER;
       }
 
-      if (read_wrapper(&desc, buffer, BUFLEN, &length, 0) != PRINTER_SUCCESS ||
-	  (length <= 0)) {
+      if (read_wrapper(&desc, buffer, BIG_BUFLEN, &length, 0)
+	  != PRINTER_SUCCESS || (length <= 0)) {
 
 #ifdef DEBUG    
 
@@ -394,6 +399,11 @@ int get_ink_level_canon(const int port, const char* device_file,
       indexDWS = strstr(buffer+2, "DWS:");
       indexCHD = strstr(buffer+2, "CHD:");
       indexCIR = strstr(buffer+2, "CIR:");
+
+      if (strstr(buffer, "<?xml")) {
+	xmlFound = 1;
+	break;
+      }
       
       if (close_wrapper(&desc) != PRINTER_SUCCESS) {
 
@@ -406,6 +416,15 @@ int get_ink_level_canon(const int port, const char* device_file,
     } while (!indexDOC && !indexDWS && !indexCHD && !indexCHD && --retry);
   }
 
+  if (xmlFound) {
+
+#ifdef DEBUG
+    printf("XML response detected\n");
+#endif
+
+    return parse_level_from_canon_xml((unsigned char *) buffer, level);
+  }
+
   if (!indexDOC && !indexDWS && !indexCHD && !indexCHD) {
 	  
 #ifdef DEBUG
