@@ -1,6 +1,6 @@
 /* devices.h
  *
- * (c) 2015 Markus Heinz
+ * (c) 2015, 2018 Markus Heinz
  *
  * This software is licensed under the terms of the GPL.
  * For details see file COPYING.
@@ -11,7 +11,4 @@
 
 int get_device_id(const int port, const char *device_file, 
 		  const int portnumber, char *device_id);
-int open_printer_device(const int port, const char* device_file, 
-                        const int portnumber);
-
 #endif
