@@ -1,6 +1,6 @@
 /* libusb-utils.c
  *
- * (c) 2014, 2015, 2018 Markus Heinz
+ * (c) 2014, 2015, 2018, 2022 Markus Heinz
  *
  * This software is licensed under the terms of the GPL.
  * For details see file COPYING.
@@ -29,10 +29,10 @@ typedef struct usb_printer {
   uint8_t configuration;
 } usb_printer;
 
-int init_usb(libusb_context *ctx);
-void shutdown_usb(libusb_context *ctx);
+int init_usb();
+void shutdown_usb();
 
-usb_printer *find_printer(libusb_context *ctx, int instance);
+usb_printer *find_printer(int instance);
 usb_printer *check_for_printer(libusb_device_handle *handle);
 
 int open_device_handle(usb_printer *printer);
